# BOOTSTRAP NOTE: We currently build only the base alcotest package.  We cannot
# yet build the async and lwt subpackages, because of missing dependencies.
# Some of those dependencies require the base alcotest package, either directly
# or indirectly.  Therefore, we will only be able to build the other two in
# non-bootstrap mode.

%ifnarch %{ocaml_native_compiler}
%global debug_package %{nil}
%endif

%global srcname alcotest

Name:           ocaml-%{srcname}
Version:        1.0.1
Release:        %mkrel 2
Summary:        Lightweight and colorful test framework for OCaml
Group:          Development/OCaml

License:        ISC
URL:            https://github.com/mirage/alcotest
Source0:        %{url}/releases/download/%{version}/%{srcname}-%{version}.tbz
# We neither need nor want the stdlib-shims package in Fedora.  It is a forward
# compatibility package for older OCaml installations.  Patch it out instead.
# Upstream does not want this patch until stdlib-shims is obsolete.
Patch0:         %{name}-stdlib-shims.patch

BuildRequires:  ocaml >= 4.03.0
BuildRequires:  ocaml-astring-devel
BuildRequires:  ocaml-cmdliner-devel
BuildRequires:  ocaml-dune >= 1.1.0
BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-fmt-devel >= 0.8.0
BuildRequires:  ocaml-re-devel
BuildRequires:  ocaml-uuidm-devel

%description
Alcotest is a lightweight and colorful test framework.

Alcotest exposes a simple interface to perform unit tests, including a
simple `TESTABLE` module type, a `check` function to assert test
predicates, and a `run` function to perform a list of `unit -> unit`
test callbacks.

Alcotest provides quiet and colorful output where only faulty runs are
fully displayed at the end of the run (with the full logs ready to
inspect), with a simple (yet expressive) query language to select the
tests to run.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       ocaml-cmdliner-devel%{?_isa}
Requires:       ocaml-fmt-devel%{?_isa}
Requires:       ocaml-re-devel%{?_isa}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%autosetup -n %{srcname}-%{version} -p1

%build
# For non-bootstrap builds, omit the "-p alcotest", and also run:
#   dune build %{?_smp_mflags} @doc
# to generate the documentation.
dune build %{?_smp_mflags} -p alcotest

%install
# For non-bootstrap builds, omit the "alcotest" on the end.
dune install --destdir=%{buildroot} alcotest

# We install the documentation with the doc macro
rm -fr %{buildroot}%{_prefix}/doc

# We do not want the ml files
find %{buildroot}%{_libdir}/ocaml -name \*.ml -delete

%ifarch %{ocaml_native_compiler}
# Add missing executable bits
find %{buildroot}%{_libdir}/ocaml -name \*.cmxs -exec chmod a+x {} \+
%endif

%check
dune runtest -p alcotest

%files
%doc CHANGES.md README.md
%license LICENSE.md
%dir %{_libdir}/ocaml/%{srcname}/
%{_libdir}/ocaml/%{srcname}/META
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cma
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmxs
%endif

%files devel
%{_libdir}/ocaml/%{srcname}/dune-package
%{_libdir}/ocaml/%{srcname}/opam
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{srcname}/%{srcname}*.a
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmx
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmxa
%endif
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmt
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmti
%{_libdir}/ocaml/%{srcname}/*.mli



%changelog
* Sun Jan 10 2021 pterjan <pterjan> 1.0.1-2.mga8
+ Revision: 1670767
- Rebuild to generate ocamlx provides

* Sun Apr 05 2020 tv <tv> 1.0.1-1.mga8
+ Revision: 1564926
- 1.0.1

* Fri Feb 28 2020 umeabot <umeabot> 1.0.0-4.mga8
+ Revision: 1551802
- Rebuild for ocaml 4.10.0 final

* Thu Feb 20 2020 umeabot <umeabot> 1.0.0-3.mga8
+ Revision: 1545757
- Mageia 8 Mass Rebuild

* Wed Jan 29 2020 tv <tv> 1.0.0-2.mga8
+ Revision: 1485163
- imported package ocaml-alcotest

